==> nova-16.0.0.0b2.tar.gz: nova-16.0.0.0b2/nova/policies/networks_associate.py <==
# Copyright 2016 Cloudbase Solutions Srl
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from nova.policies import base


BASE_POLICY_NAME = 'os_compute_api:os-networks-associate'


networks_associate_policies = [
    base.create_rule_default(
        BASE_POLICY_NAME,
        base.RULE_ADMIN_API,
        """Associates and Disassociates a network from a host or project.

These APIs are only available with nova-network which is deprecated.""",
        [
            {
                'method': 'POST',
                'path': '/os-networks/{network_id}/action (disassociate_host)'
            },
            {
                'method': 'POST',
                'path': '/os-networks/{network_id}/action'
                        ' (disassociate_project)'
            },
            {
                'method': 'POST',
                'path': '/os-networks/{network_id}/action (associate_host)'
            }
        ]),
]


def list_rules():
    return networks_associate_policies

==> nova_17.0.1.orig.tar.gz: nova-17.0.1/nova/policies/networks_associate.py <==
# Copyright 2016 Cloudbase Solutions Srl
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_policy import policy

from nova.policies import base


BASE_POLICY_NAME = 'os_compute_api:os-networks-associate'


networks_associate_policies = [
    policy.DocumentedRuleDefault(
        BASE_POLICY_NAME,
        base.RULE_ADMIN_API,
        """Associate or disassociate a network from a host or project.

These APIs are only available with nova-network which is deprecated.""",
        [
            {
                'method': 'POST',
                'path': '/os-networks/{network_id}/action (disassociate_host)'
            },
            {
                'method': 'POST',
                'path': '/os-networks/{network_id}/action'
                        ' (disassociate_project)'
            },
            {
                'method': 'POST',
                'path': '/os-networks/{network_id}/action (associate_host)'
            }
        ]),
]


def list_rules():
    return networks_associate_policies
